@@ -169,6 +169,10 @@ class ExtendedMinimizer(object):
             commands.append(ROOT.RooFit.NumCPU(kwargs['num_cpu'], 3))
         if 'offset' in kwargs:
             commands.append(ROOT.RooFit.Offset(kwargs['offset']))
+        if ('batch_mode' in kwargs) and hasattr(ROOT.RooFit, "BatchMode"):
+            commands.append(ROOT.RooFit.BatchMode(batch_mode))
+        if ('int_bin_precision' in kwargs) and hasattr(ROOT.RooFit, "IntegrateBins"):
+            commands.append(ROOT.RooFit.IntegrateBins(int_bin_precision))
         if constrain is not None:
             commands.append(ROOT.RooFit.Constrain(constrain))
         if global_observables is not None:
