@@ -955,11 +955,11 @@ class ExtendedModel(object):
         """
 
         if do_fit:
-            ws.saveSnapshot(con_glob_name.format(mu=poi_profile), all_globs)
-            ws.saveSnapshot(con_nuis_name.format(mu=poi_profile), all_nuis)
+            ws.saveSnapshot(con_glob_name.format(mu=pretty_value(poi_profile)), all_globs)
+            ws.saveSnapshot(con_nuis_name.format(mu=pretty_value(poi_profile)), all_nuis)
         else:
-            ws.saveSnapshot(con_glob_name.format(mu=poi_val), all_globs)
-            ws.saveSnapshot(con_nuis_name.format(mu=poi_val), all_nuis)
+            ws.saveSnapshot(con_glob_name.format(mu=pretty_value(poi_val)), all_globs)
+            ws.saveSnapshot(con_nuis_name.format(mu=pretty_value(poi_val)), all_nuis)
         
         asimov_data_name = names['asimov'].format(mu=pretty_value(poi_val), 
                                                   mu_cond=pretty_value(poi_profile))
