@@ -177,7 +177,8 @@ class Likelihood(AnalysisObject):
             return None
         return self.minimizer.fit_result.minNll()
     
-    def __init__(self, filename:str, data_name:str='combData', 
+    def __init__(self, filename:str, poi_name:Optional[str]=None,
+                 data_name:str='combData', 
                  config:Optional[Union[Dict, str]]=None):
         
         config = parse_config(config)
@@ -185,36 +186,35 @@ class Likelihood(AnalysisObject):
         config['data_name'] = data_name
         super().__init__(**config)
         
-        self.poi_bestfit = None
+        self.model.workspace.saveSnapshot("initialSnapshot", self.model.workspace.allVars())
+        self.poi = self.model.get_poi(poi_name)
         
-    def evaluate(self, poi_val:float, poi_name:Optional[str]=None, vmin:float=10., vmax:float=10., unconditional=False,
-                 hesse:bool=False, minos:bool=True):
-        
-        self.model.workspace.saveSnapshot("tmp", self.model.workspace.allVars())
+    def evaluate(self, poi_val:float, vmin:float=10., vmax:float=10., 
+                 unconditional=False, hesse:bool=False, minos:bool=True, 
+                 snapshot_name:Optional[str]="initialSnapshot"):
         
+        if snapshot_name:
+            self.model.workspace.loadSnapshot(snapshot_name)
+            
         # setup the POI
-        poi = self.model.get_poi(poi_name)
         poi_min, poi_max = poi_val - abs(vmin), poi_val + abs(vmax)
-        poi.setRange(poi_min, poi_max)
+        self.poi.setRange(poi_min, poi_max)
         
         if unconditional:
-            poi.setConstant(0)
+            self.poi.setConstant(0)
             hesse = True
         else:
-            poi.setVal(poi_val)
-            poi.setConstant(1)
+            self.poi.setVal(poi_val)
+            self.poi.setConstant(1)
 
         minimizer_options = { 
             'hesse': hesse,
             'minos': minos
         }
         if minos:
-            minimizer_options['minos_set'] = ROOT.RooArgSet(poi)
-        
+            minimizer_options['minos_set'] = ROOT.RooArgSet(self.poi)
+
         # perform the fit
         self.minimizer.minimize(**minimizer_options)
-        
-        self.poi_bestfit = poi.getVal()
-        
-        self.model.workspace.loadSnapshot("tmp")
+
         return self.minNll
\ No newline at end of file
