@@ -8,6 +8,7 @@ import sys
 import time
 import json
 import fnmatch
+from itertools import repeat
 from typing import List, Optional
 
 import uproot
@@ -79,7 +80,7 @@ class NuisanceParameterPull(object):
                    fix_param:str='', profile_param:str='', binned:bool=True,
                    workspace:Optional[str]=None, model_config:Optional[str]=None,
                    minimizer_type:str='Minuit2', minimizer_algo:str='Migrad', 
-                   precision:float=0.001, eps:float=1.0, strategy:int=0, 
+                   precision:float=0.001, eps:float=1.0, strategy:int=0, print_level:int=1,
                    num_cpu:int=1, offset:bool=True, optimize:int=2, eigen:bool=False,
                    fix_cache:bool=True, fix_multi:bool=True, max_calls:int=-1, 
                    max_iters:int=-1, batch_mode:bool=False, int_bin_precision:float=-1.,
@@ -274,10 +275,9 @@ class NuisanceParameterPull(object):
                   fix:str='', workspace:Optional[str]=None, model_config:Optional[str]=None,
                   minimizer_type:str='Minuit2', minimizer_algo:str='Migrad', num_cpu:int=1, 
                   binned:bool=1, precision:float=0.001, eps:float=1.0, log_level:str='INFO', eigen:bool=False, 
-                  strategy:int=0, fix_cache:bool=True, fix_multi:bool=True, offset:bool=True, optimize:int=2,
-                  parameter:str="", max_calls:int=-1, max_iters:int=-1, batch_mode:bool=False, 
-                  int_bin_precision:float=-1.,parallel:int=0, cache:bool=True, 
-                  exclude:str='', **kwargs):
+                  strategy:int=0, print_level:int=1, fix_cache:bool=True, fix_multi:bool=True, offset:bool=True, 
+                  optimize:int=2, parameter:str="", max_calls:int=-1, max_iters:int=-1, batch_mode:bool=False, 
+                  int_bin_precision:float=-1.,parallel:int=0, cache:bool=True, exclude:str='', **kwargs):
         
         # configure default minimizer options
         ExtendedMinimizer._configure_default_minimizer_options(minimizer_type, minimizer_algo,
@@ -306,26 +306,17 @@ class NuisanceParameterPull(object):
         else:
             logfile_paths = [None]*len(nuis_names)
             
-        if parallel:
-            from itertools import repeat
-            arguments = (repeat(input_file), repeat(data), repeat(snapshot), nuis_names, 
-                         repeat(poi), repeat(fix), repeat(profile), repeat(binned),
-                         repeat(workspace), repeat(model_config), repeat(minimizer_type), 
-                         repeat(minimizer_algo), repeat(precision), repeat(eps), repeat(strategy), 
-                         repeat(num_cpu), repeat(offset), repeat(optimize), repeat(eigen), 
-                         repeat(fix_cache), repeat(fix_multi), repeat(max_calls), repeat(max_iters),
-                         repeat(batch_mode), repeat(int_bin_precision),
-                         repeat(outdir), repeat(cache), logfile_paths)
-            max_workers = parallel if parallel != -1 else common_utils.get_cpu_count()
-            common_utils.parallel_run(self._run_pulls, *arguments, max_workers=max_workers)
-        else:
-            for i, nuis_name in enumerate(nuis_names):
-                self._run_pulls(input_file, data, snapshot, nuis_name, poi, fix, profile, 
-                                binned, workspace, model_config, minimizer_type, 
-                                minimizer_algo, precision, eps, strategy, num_cpu, offset, 
-                                optimize, eigen, fix_cache, fix_multi, max_calls, max_iters,
-                                batch_mode, int_bin_precision,
-                                outdir, cache, logfile_paths[i])
+
+        arguments = (repeat(input_file), repeat(data), repeat(snapshot), nuis_names, 
+                     repeat(poi), repeat(fix), repeat(profile), repeat(binned),
+                     repeat(workspace), repeat(model_config), repeat(minimizer_type), 
+                     repeat(minimizer_algo), repeat(precision), repeat(eps), repeat(strategy),
+                     repeat(print_level), repeat(num_cpu), repeat(offset), repeat(optimize), 
+                     repeat(eigen), repeat(fix_cache), repeat(fix_multi), repeat(max_calls), 
+                     repeat(max_iters), repeat(batch_mode), repeat(int_bin_precision),
+                     repeat(outdir), repeat(cache), logfile_paths)
+        common_utils.execute_multi_tasks(self._run_pulls, *arguments, parallel=parallel)
+
         
     @staticmethod
     def parse_root_result(fname):
